@@ -17,10 +17,10 @@ S60Trail *trail = new S60Trail(0);
     app.setNavigationMode(Qt::NavigationModeKeypadTabOrder);
     trail->showMaximized();
 #elif defined(Q_WS_MAEMO_5) || defined(MEEGO) || defined(Q_WS_MAEMO_6)
-    trail->showMaximized();
+    trail->showFullScreen();
 #else
-//This should say show(), but the MEEGO define isnt working
-    trail->showMaximized();
+    //This should say show(), but the MEEGO define isnt working
+    trail->show();
 #endif
 
 return app.exec();
