@@ -10,6 +10,11 @@
 #include <QApplication>
 #include <QHBoxLayout>
 
+#ifdef Q_WS_MAEMO_5
+#include <QtDBus/QDBusConnection>
+#include <QtDBus/QDBusMessage>
+#endif
+
 #include "traillogin.h"
 #include "trailmainmenu.h"
 #include "trailtripslist.h"
@@ -99,6 +104,12 @@ S60Trail::S60Trail(QWidget *parent) : QWidget(parent)
     connect(m_backAction, SIGNAL(triggered()), this, SLOT(slotBack()));
     addAction(m_backAction);
 
+    //Minimize Button
+    m_minimizeAction = new QAction(QIcon(":/images/gps-red.png"), "Minimize", this);
+    m_minimizeAction->setSoftKeyRole(QAction::NegativeSoftKey);
+    connect(m_minimizeAction, SIGNAL(triggered()), this, SLOT(slotMinimize()));
+    addAction(m_minimizeAction);
+
 #ifndef Q_OS_SYMBIAN
     m_backButton = new QToolButton(this);
     m_backButton->setDefaultAction(m_backAction);
@@ -106,6 +117,14 @@ S60Trail::S60Trail(QWidget *parent) : QWidget(parent)
     m_titleLayout->addWidget(m_backButton);
 #endif
 
+    m_minimizeButton = new QToolButton(this);
+    m_minimizeButton->setDefaultAction(m_minimizeAction);
+    m_minimizeButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
+    m_titleLayout->insertWidget(0, m_minimizeButton);
+
+    connect(m_interface.location(), SIGNAL(positionUpdated(const QGeoPositionInfo&)), this, SLOT(positionUpdated(const QGeoPositionInfo&)));
+    connect(m_minimizeAction, SIGNAL(triggered()), this, SLOT(slotMinimize()));
+
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 #endif
@@ -241,3 +260,26 @@ void S60Trail::hideBusyIndicator()
 #endif
 }
 
+void S60Trail::positionUpdated(const QGeoPositionInfo& pos)
+{
+    if (pos.attribute(QGeoPositionInfo::HorizontalAccuracy) <= 20) {
+        m_minimizeAction->setIcon(QIcon(":/images/gps-green.png"));
+    } else if (pos.attribute(QGeoPositionInfo::HorizontalAccuracy) <= 50) {
+        m_minimizeAction->setIcon(QIcon(":/images/gps-amber.png"));
+    } else {
+        m_minimizeAction->setIcon(QIcon(":/images/gps-red.png"));
+    }
+}
+
+void S60Trail::slotMinimize()
+{
+#ifdef Q_WS_MAEMO_5
+    QDBusConnection c = QDBusConnection::sessionBus();
+    QDBusMessage m = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
+    c.send(m);
+    c.send(m);
+#else
+    showMinimized();
+#endif
+
+}
