@@ -37,6 +37,10 @@ TrailGPXRecorder::TrailGPXRecorder(TrailInterface *interface, QWidget *parent) :
     m_curLatitude->setFocusPolicy(Qt::TabFocus);
     m_layout->addWidget(m_curLatitude);
 
+    m_curAccuracy = new QLabel("<b>Accuracy: </b>unavailable", this);
+    m_curAccuracy->setFocusPolicy(Qt::TabFocus);
+    m_layout->addWidget(m_curAccuracy);
+
     m_btnLayout = new QHBoxLayout();
     
     m_record = new QPushButton(QIcon(":/images/media-record.png"), QString(), this);
@@ -80,6 +84,8 @@ TrailGPXRecorder::TrailGPXRecorder(TrailInterface *interface, QWidget *parent) :
     }
 
     m_currentCircle = new QGeoMapCircleObject();
+    m_accuracyCircle = new QGeoMapCircleObject();
+
     m_poly = new QGeoMapPolylineObject();
     m_poly->setPen(QPen(Qt::red));
 
@@ -88,11 +94,18 @@ TrailGPXRecorder::TrailGPXRecorder(TrailInterface *interface, QWidget *parent) :
     m_poly->setPath(invalid);
 
     m_currentCircle->setCenter(QGeoCoordinate(54.612293,-3.227448));
-    m_currentCircle->setRadius(15);
+    m_currentCircle->setRadius(5);
     m_currentCircle->setPen(QPen(Qt::red, 3));
-    m_currentCircle->setBrush(QBrush(QColor(128,0,0,128)));
+    m_currentCircle->setBrush(QBrush(Qt::red));
+
+    m_accuracyCircle->setCenter(QGeoCoordinate(54.612293,-3.227448));
+    m_accuracyCircle->setRadius(30);
+    m_accuracyCircle->setPen(QPen(Qt::red, 1));
+    m_accuracyCircle->setBrush(QBrush(QColor(128, 0, 0, 64)));
 
     m_mapWidget->addMapObject(m_currentCircle);
+    m_mapWidget->addMapObject(m_accuracyCircle);
+
     m_mapWidget->addMapObject(m_poly);
     m_mapWidget->setCenter(m_currentCircle->center());
 }
@@ -153,10 +166,11 @@ void TrailGPXRecorder::positionUpdated(const QGeoPositionInfo& pos)
 {
     m_curLatitude->setText(QString("<b>Latitude: </b>%1").arg(pos.coordinate().latitude()));
     m_curLongitude->setText(QString("<b>Longitude: </b>%1").arg(pos.coordinate().longitude()));
+    m_curAccuracy->setText(QString("<b>Accuracy: </b>%1").arg(pos.attribute(QGeoPositionInfo::HorizontalAccuracy)));
 
     if (width() > height()) {
         //Landscape
-        m_curPos->setText(QString("<b>Current Position: </b>%1:%2").arg(pos.coordinate().latitude()).arg(pos.coordinate().longitude()));
+        m_curPos->setText(QString("<b>Current Position: </b>%1/%2/%3").arg(m_model->currentPosition().coordinate().latitude()).arg(m_model->currentPosition().coordinate().longitude()).arg(m_model->currentPosition().attribute(QGeoPositionInfo::HorizontalAccuracy)));
     }
     else {
         //Portrait
@@ -164,6 +178,8 @@ void TrailGPXRecorder::positionUpdated(const QGeoPositionInfo& pos)
     }
 
     m_currentCircle->setCenter(pos.coordinate());
+    m_accuracyCircle->setCenter(pos.coordinate());
+    m_accuracyCircle->setRadius(pos.attribute(QGeoPositionInfo::HorizontalAccuracy));
 
     m_path.clear();
 
@@ -171,6 +187,8 @@ void TrailGPXRecorder::positionUpdated(const QGeoPositionInfo& pos)
         m_path << QGeoCoordinate(m_model->data(m_model->index(i, 2)).toDouble(), m_model->data(m_model->index(i, 2)).toDouble());
     }
 
+    qDebug()<< m_path;
+
     m_poly->setPath(m_path);
     m_mapWidget->setCenter(m_currentCircle->center());
 }
@@ -181,14 +199,16 @@ void TrailGPXRecorder::resizeEvent(QResizeEvent *event)
         //Landscape
         m_curLongitude->hide();
         m_curLatitude->hide();
+        m_curAccuracy->hide();
 
         if (m_model) {
-            m_curPos->setText(QString("<b>Current Position: </b>%1:%2").arg(m_model->currentPosition().coordinate().latitude()).arg(m_model->currentPosition().coordinate().longitude()));
+            m_curPos->setText(QString("<b>Current Position: </b>%1/%2/%3").arg(m_model->currentPosition().coordinate().latitude()).arg(m_model->currentPosition().coordinate().longitude()).arg(m_model->currentPosition().attribute(QGeoPositionInfo::HorizontalAccuracy)));
         }
     } else {
         //Portrait
         m_curLongitude->show();
         m_curLatitude->show();
+        m_curAccuracy->show();
         m_curPos->setText("<b>Current Position:</b>");
     }
 }
