@@ -32,6 +32,7 @@ private:
     QLabel *m_curPos;
     QLabel *m_curLongitude;
     QLabel *m_curLatitude;
+    QLabel *m_curAccuracy;
     QTableView *m_gpxList;
     QPushButton *m_record;
     QPushButton *m_stop;
@@ -50,6 +51,7 @@ private:
     TrailTrackModel *m_model;
 
     QGeoMapCircleObject *m_currentCircle;
+    QGeoMapCircleObject *m_accuracyCircle;
     QList<QGeoCoordinate> m_path;
     QGeoMapPolylineObject *m_poly;
 
