@@ -22,6 +22,7 @@ private:
     QLineEdit *m_user;
     QLineEdit *m_pass;
     QPushButton *m_loginButton;
+    QPushButton *m_dontLoginButton;
     QCheckBox *m_remember;
 
     QVBoxLayout *m_layout;
@@ -33,6 +34,7 @@ signals:
 private slots:
     void slotLoginClicked();
     void slotLoginReceived(long id);
+    void slotDontLogin();
 };
 
 #endif // TRAILLOGIN_H
